aboutsummaryrefslogtreecommitdiffstats
path: root/ui/tap-iax2-analysis.h
diff options
context:
space:
mode:
authorJiri Novak <j.novak@netsystem.cz>2018-06-14 23:19:01 +0200
committerAnders Broman <a.broman58@gmail.com>2018-06-19 15:05:12 +0000
commit27a1906c582b9c7dcd17e7db2726a1059e3aaf8a (patch)
tree44b713c72d6c5cac6ca9f319cc8c8511d8597834 /ui/tap-iax2-analysis.h
parent434fbe20dd5e2dc58473fea1363a7350486bc33c (diff)
RTP: Code clean up
Changes: - rtpstream_packet renamed to rtpstream_packet_cb to follow *_cb pattern - variables/types used in iax2_analysis_dialog were created as copy of *rtp* ones, but names were left as *rtp* -> *iax2* - struct _rtp_stream_info replaced with rtp_stream_info_t - there was tap-rtp-analysis.h, but no tap-rtp-analysis.c - related content was moved from tap-rtp-common.c - *rtp_stream* functions renamed to *rtpstream* - renamed rtp_stream_info_t to rtpstream_info_t to follow *rtpstream* pattern. - renamed ui/rtp_stream.c rtpstream_draw -> rtpstream_draw_cb Change-Id: Ib11ff5367cc464ea1b0c73432bc50b0eb9cd203e Reviewed-on: https://code.wireshark.org/review/28299 Reviewed-by: Anders Broman <a.broman58@gmail.com>
Diffstat (limited to 'ui/tap-iax2-analysis.h')
-rw-r--r--ui/tap-iax2-analysis.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ui/tap-iax2-analysis.h b/ui/tap-iax2-analysis.h
index b88b9fd076..fc12717666 100644
--- a/ui/tap-iax2-analysis.h
+++ b/ui/tap-iax2-analysis.h
@@ -41,10 +41,10 @@ typedef struct _iax2_bw_history_item {
#define BUFF_BW 300
typedef struct _tap_iax2_stat_t {
- gboolean first_packet; /* do not use in code that is called after rtp_packet_analyse */
+ gboolean first_packet; /* do not use in code that is called after iax2_packet_analyse */
/* use (flags & STAT_FLAG_FIRST) instead */
/* all of the following fields will be initialized after
- rtp_packet_analyse has been called */
+ iax2_packet_analyse has been called */
guint32 flags; /* see STAT_FLAG-defines below */
guint16 seq_num;
guint32 timestamp;